var E=Object.defineProperty;var O=(t,e,n)=>e in t?E(t,e,{enumerable:!0,configurable:!0,writable:!0,value:n}):t[e]=n;var _=(t,e,n)=>O(t,typeof e!="symbol"?e+"":e,n);import{r as $,n as c,J as v,K as b,L as C,M as p,f as I,d as L,N as M,O as x,P as N,Q as w,R as P,S as R,T as U,U as V,V as j}from"./DVvjRtkd.js";const u=new Set;let f;function D(){f={r:0,c:[],p:f}}function F(){f.r||$(f.c),f=f.p}function B(t,e){t&&t.i&&(u.delete(t),t.i(e))}function G(t,e,n,a){if(t&&t.o){if(u.has(t))return;u.add(t),f.c.push(()=>{u.delete(t),a&&(n&&t.d(1),a())}),t.o(e)}else a&&a()}function H(t){t&&t.c()}function W(t,e){t&&t.l(e)}function J(t,e,n){const{fragment:a,after_update:i}=t.$$;a&&a.m(e,n),w(()=>{const d=t.$$.on_mount.map(P).filter(v);t.$$.on_destroy?t.$$.on_destroy.push(...d):$(d),t.$$.on_mount=[]}),i.forEach(w)}function K(t,e){const n=t.$$;n.fragment!==null&&(N(n.after_update),$(n.on_destroy),n.fragment&&n.fragment.d(e),n.on_destroy=n.fragment=null,n.ctx=[])}function Q(t,e){t.$$.dirty[0]===-1&&(V.push(t),j(),t.$$.dirty.fill(0)),t.$$.dirty[e/31|0]|=1<<e%31}function X(t,e,n,a,i,d,l=null,S=[-1]){const o=C;x(t);const s=t.$$={fragment:null,ctx:[],props:d,update:c,not_equal:i,bound:p(),on_mount:[],on_destroy:[],on_disconnect:[],before_update:[],after_update:[],context:new Map(e.context||(o?o.$$.context:[])),callbacks:p(),dirty:S,skip_bound:!1,root:e.target||o.$$.root};l&&l(s.root);let h=!1;if(s.ctx=n?n(t,e.props||{},(r,g,...m)=>{const y=m.length?m[0]:g;return s.ctx&&i(s.ctx[r],s.ctx[r]=y)&&(!s.skip_bound&&s.bound[r]&&s.bound[r](y),h&&Q(t,r)),g}):[],s.update(),h=!0,$(s.before_update),s.fragment=a?a(s.ctx):!1,e.target){if(e.hydrate){R();const r=I(e.target);s.fragment&&s.fragment.l(r),r.forEach(L)}else s.fragment&&s.fragment.c();e.intro&&B(t.$$.fragment),J(t,e.target,e.anchor),U(),M()}x(o)}class Y{constructor(){_(this,"$$");_(this,"$$set")}$destroy(){K(this,1),this.$destroy=c}$on(e,n){if(!v(n))return c;const a=this.$$.callbacks[e]||(this.$$.callbacks[e]=[]);return a.push(n),()=>{const i=a.indexOf(n);i!==-1&&a.splice(i,1)}}$set(e){this.$$set&&!b(e)&&(this.$$.skip_bound=!0,this.$$set(e),this.$$.skip_bound=!1)}}const T="4";typeof window<"u"&&(window.__svelte||(window.__svelte={v:new Set})).v.add(T);export{Y as S,B as a,H as b,F as c,K as d,W as e,D as g,X as i,J as m,G as t};
