.dropzone.svelte-1d35cii{cursor:pointer;border-radius:.75rem;border-width:2px;border-style:dashed;--tw-border-opacity:1;border-color:rgb(203 213 225 / var(--tw-border-opacity, 1));padding:2rem;transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.dropzone.svelte-1d35cii:hover{--tw-border-opacity:1;border-color:rgb(167 139 250 / var(--tw-border-opacity, 1));--tw-bg-opacity:1;background-color:rgb(245 243 255 / var(--tw-bg-opacity, 1))}.dropzone.drag-over.svelte-1d35cii{--tw-border-opacity:1;border-color:rgb(139 92 246 / var(--tw-border-opacity, 1));--tw-bg-opacity:1;background-color:rgb(237 233 254 / var(--tw-bg-opacity, 1))}.file-item.svelte-1d35cii{display:flex;align-items:center;justify-content:space-between;border-radius:.5rem;border-width:1px;--tw-border-opacity:1;border-color:rgb(226 232 240 / var(--tw-border-opacity, 1));--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity, 1));padding:.75rem;transition-property:box-shadow;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.file-item.svelte-1d35cii:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / .1), 0 2px 4px -2px rgb(0 0 0 / .1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.icon-container.svelte-1g9xwwe{display:flex;height:4rem;width:4rem;align-items:center;justify-content:center;border-radius:.75rem;--tw-shadow:0 10px 15px -3px rgb(0 0 0 / .1), 0 4px 6px -4px rgb(0 0 0 / .1);--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}
