import{s as i,n as a,d as l,i as c,a as o,c as d,g as m,e as p}from"../chunks/DVvjRtkd.js";import{S as h,i as f}from"../chunks/Ca9JqCu1.js";function g(n){let e,s='<div class="card max-w-md w-full text-center py-12"><div class="text-6xl mb-4">😞</div> <h1 class="text-3xl font-bold text-orange-600 mb-4">Payment Cancelled</h1> <p class="text-slate-600 mb-8">Your payment was cancelled. No charges were made.</p> <div class="space-y-4"><a href="/pricing" class="btn-primary block">View Pricing Again</a> <a href="/" class="btn-secondary block">Return to Homepage</a></div></div>';return{c(){e=p("div"),e.innerHTML=s,this.h()},l(t){e=d(t,"DIV",{class:!0,"data-svelte-h":!0}),m(e)!=="svelte-1rviqou"&&(e.innerHTML=s),this.h()},h(){o(e,"class","min-h-screen bg-gradient-to-br from-orange-50 to-red-100 flex items-center justify-center p-6")},m(t,r){c(t,e,r)},p:a,i:a,o:a,d(t){t&&l(e)}}}class x extends h{constructor(e){super(),f(this,e,null,g,i,{})}}export{x as component};
