import{s as J,y as K,d as p,z as Q,A as W,B as X,i as A,b as o,a as r,c as i,f as D,g as v,j as w,e as c,l as k,o as Y,n as U,m as Z}from"../chunks/DVvjRtkd.js";import{S as tt,i as et,t as st,a as at}from"../chunks/Ca9JqCu1.js";import{a as lt}from"../chunks/BSu-bEiK.js";function nt(u){let t,l="Login";return{c(){t=c("a"),t.textContent=l,this.h()},l(e){t=i(e,"A",{href:!0,class:!0,"data-svelte-h":!0}),v(t)!=="svelte-1xp6wew"&&(t.textContent=l),this.h()},h(){r(t,"href","/login"),r(t,"class","badge bg-white text-primary-700 px-4 py-2 font-bold hover:bg-purple-100 transition-colors")},m(e,s){A(e,t,s)},p:U,d(e){e&&p(t)}}}function rt(u){let t,l="Dashboard",e,s,f="Logout",b,_;return{c(){t=c("a"),t.textContent=l,e=k(),s=c("button"),s.textContent=f,this.h()},l(a){t=i(a,"A",{href:!0,class:!0,"data-svelte-h":!0}),v(t)!=="svelte-110pmrh"&&(t.textContent=l),e=w(a),s=i(a,"BUTTON",{class:!0,"data-svelte-h":!0}),v(s)!=="svelte-13gnt1p"&&(s.textContent=f),this.h()},h(){r(t,"href","/dashboard"),r(t,"class","text-white hover:text-purple-200 transition-colors font-medium"),r(s,"class","text-white hover:text-purple-200 transition-colors font-medium")},m(a,x){A(a,t,x),A(a,e,x),A(a,s,x),b||(_=Z(s,"click",u[3]),b=!0)},p:U,d(a){a&&(p(t),p(e),p(s)),b=!1,_()}}}function ot(u){let t,l="API Disconnected";return{c(){t=c("span"),t.textContent=l,this.h()},l(e){t=i(e,"SPAN",{class:!0,"data-svelte-h":!0}),v(t)!=="svelte-2lr1ie"&&(t.textContent=l),this.h()},h(){r(t,"class","badge bg-red-500 text-white text-xs")},m(e,s){A(e,t,s)},d(e){e&&p(t)}}}function it(u){let t,l=`<span class="w-2 h-2 bg-white rounded-full inline-block mr-1 animate-pulse"></span>
              API Connected`;return{c(){t=c("span"),t.innerHTML=l,this.h()},l(e){t=i(e,"SPAN",{class:!0,"data-svelte-h":!0}),v(t)!=="svelte-nv9u24"&&(t.innerHTML=l),this.h()},h(){r(t,"class","badge bg-green-500 text-white text-xs")},m(e,s){A(e,t,s)},d(e){e&&p(t)}}}function ct(u){let t,l,e,s,f,b='<span class="text-3xl">✨</span> <a href="/" class="text-2xl font-bold hover:text-purple-200">DataShaper AI</a> <span class="badge bg-white text-primary-700 text-xs">v3.0</span>',_,a,x,O="Home",T,g,j="Pricing",M,P,$,E,V,C,q='<div class="max-w-7xl mx-auto px-6 py-6 text-center text-sm text-slate-600"><p>DataShaper AI - Enterprise Data Healing Engine</p> <p class="mt-1 text-xs text-slate-500">Powered by Polars • 10x Faster</p></div>',I;function G(n,h){return typeof sessionStorage<"u"&&sessionStorage.getItem("auth_token")?rt:nt}let H=G()(u);function B(n,h){return n[0]?it:ot}let L=B(u),m=L(u);const N=u[2].default,d=K(N,u,u[1],null);return{c(){t=c("div"),l=c("header"),e=c("div"),s=c("div"),f=c("div"),f.innerHTML=b,_=k(),a=c("div"),x=c("a"),x.textContent=O,T=k(),g=c("a"),g.textContent=j,M=k(),H.c(),P=k(),m.c(),$=k(),E=c("main"),d&&d.c(),V=k(),C=c("footer"),C.innerHTML=q,this.h()},l(n){t=i(n,"DIV",{class:!0});var h=D(t);l=i(h,"HEADER",{class:!0});var F=D(l);e=i(F,"DIV",{class:!0});var R=D(e);s=i(R,"DIV",{class:!0});var S=D(s);f=i(S,"DIV",{class:!0,"data-svelte-h":!0}),v(f)!=="svelte-v9a1da"&&(f.innerHTML=b),_=w(S),a=i(S,"DIV",{class:!0});var y=D(a);x=i(y,"A",{href:!0,class:!0,"data-svelte-h":!0}),v(x)!=="svelte-1xod8fy"&&(x.textContent=O),T=w(y),g=i(y,"A",{href:!0,class:!0,"data-svelte-h":!0}),v(g)!=="svelte-yqovk1"&&(g.textContent=j),M=w(y),H.l(y),P=w(y),m.l(y),y.forEach(p),S.forEach(p),R.forEach(p),F.forEach(p),$=w(h),E=i(h,"MAIN",{});var z=D(E);d&&d.l(z),z.forEach(p),V=w(h),C=i(h,"FOOTER",{class:!0,"data-svelte-h":!0}),v(C)!=="svelte-1vnot3f"&&(C.innerHTML=q),h.forEach(p),this.h()},h(){r(f,"class","flex items-center space-x-3"),r(x,"href","/"),r(x,"class","text-white hover:text-purple-200 transition-colors font-medium"),r(g,"href","/pricing"),r(g,"class","text-white hover:text-purple-200 transition-colors font-medium"),r(a,"class","flex items-center space-x-6"),r(s,"class","flex items-center justify-between"),r(e,"class","max-w-7xl mx-auto px-6 py-4"),r(l,"class","bg-gradient-to-r from-primary-600 to-purple-600 text-white shadow-lg"),r(C,"class","bg-white border-t border-slate-200 mt-12"),r(t,"class","min-h-screen")},m(n,h){A(n,t,h),o(t,l),o(l,e),o(e,s),o(s,f),o(s,_),o(s,a),o(a,x),o(a,T),o(a,g),o(a,M),H.m(a,null),o(a,P),m.m(a,null),o(t,$),o(t,E),d&&d.m(E,null),o(t,V),o(t,C),I=!0},p(n,[h]){H.p(n,h),L!==(L=B(n))&&(m.d(1),m=L(n),m&&(m.c(),m.m(a,null))),d&&d.p&&(!I||h&2)&&Q(d,N,n,n[1],I?X(N,n[1],h,null):W(n[1]),null)},i(n){I||(at(d,n),I=!0)},o(n){st(d,n),I=!1},d(n){n&&p(t),H.d(),m.d(),d&&d.d(n)}}}function ut(u,t,l){let{$$slots:e={},$$scope:s}=t,f=!1;Y(async()=>{try{await lt.healthCheck(),l(0,f=!0)}catch(_){console.error("API health check failed:",_)}});const b=()=>{sessionStorage.clear(),window.location.href="/"};return u.$$set=_=>{"$$scope"in _&&l(1,s=_.$$scope)},[f,s,e,b]}class xt extends tt{constructor(t){super(),et(this,t,ut,ct,J,{})}}export{xt as component};
