import{s as S,n as _,d as l,h as f,i as m,b as d,c as g,f as h,k as v,j as x,e as $,t as E,l as C,C as j}from"../chunks/DVvjRtkd.js";import{S as k,i as q}from"../chunks/Ca9JqCu1.js";import{s as y}from"../chunks/BkgRu8QA.js";const H=()=>{const s=y;return{page:{subscribe:s.page.subscribe},navigating:{subscribe:s.navigating.subscribe},updated:s.updated}},P={subscribe(s){return H().page.subscribe(s)}};function w(s){var b;let t,r=s[0].status+"",o,n,i,c=((b=s[0].error)==null?void 0:b.message)+"",u;return{c(){t=$("h1"),o=E(r),n=C(),i=$("p"),u=E(c)},l(e){t=g(e,"H1",{});var a=h(t);o=v(a,r),a.forEach(l),n=x(e),i=g(e,"P",{});var p=h(i);u=v(p,c),p.forEach(l)},m(e,a){m(e,t,a),d(t,o),m(e,n,a),m(e,i,a),d(i,u)},p(e,[a]){var p;a&1&&r!==(r=e[0].status+"")&&f(o,r),a&1&&c!==(c=((p=e[0].error)==null?void 0:p.message)+"")&&f(u,c)},i:_,o:_,d(e){e&&(l(t),l(n),l(i))}}}function z(s,t,r){let o;return j(s,P,n=>r(0,o=n)),[o]}let F=class extends k{constructor(t){super(),q(this,t,z,w,S,{})}};export{F as component};
